/***************************************************************************/
/*                                                                         */
/*  afindic.h                                                              */
/*                                                                         */
/*    Auto-fitter hinting routines for Indic scripts (specification).      */
/*                                                                         */
/*  Copyright 2007, 2012, 2013 by                                          */
/*  Rahul Bhalerao <rahul.bhalerao@redhat.com>, <b.rahul.pm@gmail.com>.    */
/*                                                                         */
/*  This file is part of the FreeType project, and may only be used,       */
/*  modified, and distributed under the terms of the FreeType project      */
/*  license, LICENSE.TXT.  By continuing to use, modify, or distribute     */
/*  this file you indicate that you have read the license and              */
/*  understand and accept it fully.                                        */
/*                                                                         */
/***************************************************************************/


#ifndef __AFINDIC_H__
#define __AFINDIC_H__

#include "afhints.h"


FT_BEGIN_HEADER


  /* the `indic' writing system */

  AF_DECLARE_WRITING_SYSTEM_CLASS( af_indic_writing_system_class )


  /* the indic-specific script classes */

  AF_DECLARE_SCRIPT_CLASS( af_deva_script_class )


/* */

FT_END_HEADER

#endif /* __AFINDIC_H__ */


/* END */
